Summary:        Scalable Video Technology for AV1 (SVT-AV1 Encoder and Decoder)
Name:           svt-av1
Version:        2.0.0
Release:        1%{?dist}
License:        BSD-3-Clause and MIT and ISC and Public Domain
URL:            https://gitlab.com/AOMediaCodec/SVT-AV1
Source0:        %url/-/archive/v%{version}/%{name}-%{version}.tar.bz2

BuildRequires:  gcc gcc-c++ cmake meson yasm help2man
BuildRequires:  gstreamer1-devel gstreamer1-plugins-base-devel
Requires:       %{name}-libs = %{version}-%{release}

%description
The Scalable Video Technology for AV1 (SVT-AV1 Encoder and Decoder) is an
AV1-compliant software encoder/decoder library. The work on the SVT-AV1 encoder
targets the development of a production-quality AV1-encoder with performance
levels applicable to a wide range of applications, from premium VOD to
real-time and live encoding/transcoding. The SVT-AV1 decoder implementation
targets future codec research activities.


%package libs
Summary:    SVT-AV1 libraries

%description libs
This package contains libraries for %{name}.


%package devel
Summary:    Development files for SVT-AV1
Requires:   %{name}-libs = %{version}-%{release}

%description devel
This package contains the development files and documentations for %{name}.


%package -n     gstreamer1-%{name}
Summary:        GStreamer 1.0 %{name}-based plug-in
Requires:       gstreamer1-plugins-base

%description -n gstreamer1-%{name}
This package provides %{name}-based GStreamer plug-in.


%prep
%global commitid 2aeeb4f1a1d495b84bf5c21dbb60ae10e991fada

%autosetup -p1 -n SVT-AV1-v%{version}-%{commitid}
sed -e "s|install: true,|install: true, include_directories : [ include_directories('../Source/API') ], link_args : '-lSvtAv1Enc',|" \
-e "/svtav1enc_dep =/d" -e 's|, svtav1enc_dep||' -e "s|svtav1enc_dep.found()|true|" -i gstreamer-plugin/meson.build


%build
%cmake -DCMAKE_BUILD_TYPE=RelWithDebInfo
%cmake_build

export LIBRARY_PATH="$LIBRARY_PATH:$(pwd)/Bin/RelWithDebInfo"
pushd gstreamer-plugin
%meson
%meson_build
popd


%install
%cmake_install
rm -f %{buildroot}%{_libdir}/*.{a,la}

install -d -m 0755 %{buildroot}/%{_mandir}/man1
export LD_LIBRARY_PATH=$LD_LIBRARY_PATH:%{buildroot}%{_libdir}
help2man -N --help-option=-help --version-string=%{version} %{buildroot}%{_bindir}/SvtAv1DecApp > \
         %{buildroot}%{_mandir}/man1/SvtAv1DecApp.1
help2man -N --help-option=-help --no-discard-stderr --version-string=%{version} %{buildroot}%{_bindir}/SvtAv1EncApp > \
         %{buildroot}%{_mandir}/man1/SvtAv1EncApp.1

pushd gstreamer-plugin
%meson_install
popd


%files
%{_bindir}/SvtAv1DecApp
%{_bindir}/SvtAv1EncApp
%{_mandir}/man1/SvtAv1DecApp.1*
%{_mandir}/man1/SvtAv1EncApp.1*


%files libs
%license LICENSE.md PATENTS.md
%doc CHANGELOG.md CONTRIBUTING.md README.md
%{_libdir}/libSvtAv1Dec.so.0*
%{_libdir}/libSvtAv1Enc.so*


%files devel
%doc Docs
%{_libdir}/libSvtAv1Dec.so
%{_libdir}/libSvtAv1Enc.so
%{_libdir}/pkgconfig/SvtAv1Dec.pc
%{_libdir}/pkgconfig/SvtAv1Enc.pc
%{_includedir}/%{name}


%files -n gstreamer1-%{name}
%{_libdir}/gstreamer-1.0/libgstsvtav1enc.so


%changelog
* Mon Mar 18 2024 Upgrade Robot <upbot@opencloudos.org> - 2.0.0-1
- Upgrade to version 2.0.0

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.1-4
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 17 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.4.1-3
- Rebuilt for gstreamer1-plugins-base 1.22.4

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.4.1-2
- Rebuilt for OpenCloudOS Stream 23.05

* Wed Apr 19 2023 rockerzhu <rockerzhu@tencent.com> - 1.4.1-1
- Initial build
